@@ -1,8 +1,9 @@
 # from rest_framework import routers
-from .views import InvitationViewSet, accept_invitation, UserViewSet, GroupViewSet, PermissionViewSet, ContenttypeViewSet, GroupOptionsViewSet, CUserViewSet, CGroupViewSet, signup
+from .views import InvitationViewSet, accept_invitation, UserViewSet, GroupViewSet, PermissionViewSet, ContenttypeViewSet, GroupOptionsViewSet, CUserViewSet, CGroupViewSet, signup,UserTokenPairView
 from django.conf.urls import include, url
 from xtrm_drest.routers import DynamicRouter
-
+from rest_framework_simplejwt.views import TokenRefreshView
+from django.urls import path
 # router = routers.SimpleRouter()
 router = DynamicRouter()
 router.register('users', UserViewSet)
@@ -35,4 +36,6 @@ invitations_patterns = (
 
 urlpatterns = router.urls + [
     url(r'^', include(invitations_patterns)),
+    path('token/refresh/', TokenRefreshView.as_view(), name='token_refresh'),
+    path('login/', UserTokenPairView.as_view(), name='token_obtain_pair'),
 ]
